@@ -17,19 +17,13 @@
  *  02110-1301, USA.
  */
 
-#include <config.h>
-#include <string.h>
 #include <gio/gio.h>
-#include <libxfce4ui/libxfce4ui.h>
-#include <libexif/exif-data.h>
-#include <cairo/cairo.h>
 
 #include <math.h>
 
 #include "util.h"
 #include "image_viewer.h"
 #include "settings.h"
-#include "marshal.h"
 
 /* Do not make this buffer too large,
  * this breaks some pixbufloaders.
@@ -39,7 +33,7 @@
 #endif
 
 #ifndef BACKGROUND_ICON_NAME
-#define BACKGROUND_ICON_NAME "ristretto"
+#define BACKGROUND_ICON_NAME "org.xfce.ristretto"
 #endif
 
 #ifndef BACKGROUND_ICON_SIZE
@@ -75,8 +69,6 @@ struct _RsttoImageViewerPriv
 {
     RsttoFile                   *file;
     RsttoSettings               *settings;
-    GdkVisual                   *visual;
-    //GdkColormap                 *colormap;
 
     GtkIconTheme                *icon_theme;
     GdkPixbuf                   *missing_icon;
@@ -176,10 +168,6 @@ paint_background_icon (
         cairo_t *ctx );
 
 
-static void
-rstto_image_viewer_init (RsttoImageViewer *viewer);
-static void
-rstto_image_viewer_class_init(RsttoImageViewerClass *);
 static void
 rstto_image_viewer_dispose (GObject *object);
 
@@ -234,7 +222,7 @@ cb_rstto_image_loader_size_prepared (GdkPixbufLoader *, gint , gint , RsttoImage
 static void
 cb_rstto_image_loader_closed (GdkPixbufLoader *loader, RsttoImageViewerTransaction *transaction);
 static gboolean
-cb_rstto_image_viewer_update_pixbuf (RsttoImageViewer *viewer);
+cb_rstto_image_viewer_update_pixbuf (gpointer user_data);
 static void
 cb_rstto_image_viewer_dnd (GtkWidget *widget, GdkDragContext *context, gint x, gint y, GtkSelectionData *data,
                            guint info, guint time_, RsttoImageViewer *viewer);
@@ -292,8 +280,6 @@ static GdkScreen      *default_screen = NULL;
 
 G_DEFINE_TYPE_WITH_CODE (RsttoImageViewer, rstto_image_viewer, GTK_TYPE_WIDGET,
              G_IMPLEMENT_INTERFACE (GTK_TYPE_SCROLLABLE, NULL))
-//G_DEFINE_TYPE (RsttoImageViewer, rstto_image_viewer, GTK_TYPE_WIDGET)
-
 
 
 static void
@@ -309,9 +295,6 @@ rstto_image_viewer_init (RsttoImageViewer *viewer)
     viewer->priv->settings = rstto_settings_new ();
     viewer->priv->image_width = 0;
     viewer->priv->image_height = 0;
-    viewer->priv->visual = gdk_visual_get_system ();
-    // TODO: comment out for now
-    //viewer->priv->colormap = gdk_colormap_new (viewer->priv->visual, TRUE);
 
     viewer->priv->icon_theme = gtk_icon_theme_get_default ();
     viewer->priv->bg_icon = gtk_icon_theme_load_icon (
@@ -512,11 +495,8 @@ rstto_image_viewer_realize(GtkWidget *widget)
     attributes.window_type = GDK_WINDOW_CHILD;
     attributes.event_mask = gtk_widget_get_events (widget) | GDK_EXPOSURE_MASK | GDK_BUTTON_PRESS_MASK;
     attributes.visual = gtk_widget_get_visual (widget);
-    // TODO: comment out for now
-    //attributes.colormap = gtk_widget_get_colormap (widget);
 
-    // TODO: comment out for now
-    attributes_mask = GDK_WA_X | GDK_WA_Y | GDK_WA_VISUAL /*| GDK_WA_COLORMAP*/;
+    attributes_mask = GDK_WA_X | GDK_WA_Y | GDK_WA_VISUAL;
     window = gdk_window_new (gtk_widget_get_parent_window(widget), &attributes, attributes_mask);
     gtk_widget_set_window (widget, window);
     gdk_window_set_user_data (window, widget);
@@ -1911,6 +1891,12 @@ rstto_image_viewer_set_scale (RsttoImageViewer *viewer, gdouble scale)
             FALSE);
 }
 
+GdkPixbuf *
+rstto_image_viewer_get_pixbuf (RsttoImageViewer *viewer)
+{
+    return viewer->priv->pixbuf;
+}
+
 gdouble
 rstto_image_viewer_get_scale (RsttoImageViewer *viewer)
 {
@@ -2113,7 +2099,7 @@ cb_rstto_image_loader_image_ready (GdkPixbufLoader *loader, RsttoImageViewerTran
         if (timeout > 0)
         {
             viewer->priv->animation_timeout_id =
-                    gdk_threads_add_timeout (timeout, (GSourceFunc) cb_rstto_image_viewer_update_pixbuf, viewer);
+                    gdk_threads_add_timeout (timeout, cb_rstto_image_viewer_update_pixbuf, viewer);
         }
         else
         {
@@ -2127,8 +2113,6 @@ cb_rstto_image_loader_image_ready (GdkPixbufLoader *loader, RsttoImageViewerTran
 static void
 cb_rstto_image_loader_size_prepared (GdkPixbufLoader *loader, gint width, gint height, RsttoImageViewerTransaction *transaction)
 {
-    gint s_width = gdk_screen_get_width (default_screen);
-    gint s_height = gdk_screen_get_height (default_screen);
     gboolean limit_quality = transaction->viewer->priv->limit_quality;
 
     /*
@@ -2143,6 +2127,16 @@ cb_rstto_image_loader_size_prepared (GdkPixbufLoader *loader, gint width, gint h
 
     if (limit_quality == TRUE)
     {
+        GdkMonitor *monitor = gdk_display_get_monitor_at_window (
+                gdk_screen_get_display (default_screen),
+                gtk_widget_get_window (GTK_WIDGET (transaction->viewer)));
+        gint s_width, s_height;
+        GdkRectangle monitor_geometry;
+
+        gdk_monitor_get_geometry (monitor, &monitor_geometry);
+        s_width = monitor_geometry.width;
+        s_height = monitor_geometry.height;
+
         /*
          * Set the maximum size of the loaded image to the screen-size.
          * TODO: Add some 'smart-stuff' here
@@ -2227,8 +2221,9 @@ cb_rstto_image_loader_closed (GdkPixbufLoader *loader, RsttoImageViewerTransacti
 }
 
 static gboolean
-cb_rstto_image_viewer_update_pixbuf (RsttoImageViewer *viewer)
+cb_rstto_image_viewer_update_pixbuf (gpointer user_data)
 {
+    RsttoImageViewer *viewer = user_data;
     GtkWidget *widget = GTK_WIDGET (viewer);
     gint timeout = 0;
 
@@ -2255,7 +2250,7 @@ cb_rstto_image_viewer_update_pixbuf (RsttoImageViewer *viewer)
         if (timeout > 0)
         {
             viewer->priv->animation_timeout_id =
-                    gdk_threads_add_timeout(timeout, (GSourceFunc)cb_rstto_image_viewer_update_pixbuf, viewer);
+                    gdk_threads_add_timeout(timeout, cb_rstto_image_viewer_update_pixbuf, viewer);
         }
 
         gdk_window_invalidate_rect (gtk_widget_get_window (widget), NULL, FALSE);
@@ -2301,6 +2296,9 @@ rstto_scroll_event (GtkWidget *widget, GdkEventScroll *event)
                 case GDK_SCROLL_RIGHT:
                     scale = (invert_zoom_direction) ? viewer->priv->scale * 1.1 : viewer->priv->scale / 1.1;
                     break;
+                case GDK_SCROLL_SMOOTH:
+                    /* TODO */
+                    break;
             }
 
             /*
@@ -2470,7 +2468,6 @@ rstto_motion_notify_event (GtkWidget *widget, GdkEventMotion *event)
                 if (viewer->priv->motion.x != viewer->priv->motion.current_x)
                 {
                     adjustment = viewer->hadjustment;
-                    gint val = gtk_adjustment_get_value (adjustment);
                     gtk_adjustment_set_value (adjustment,
                             viewer->priv->motion.h_val + (viewer->priv->motion.x - viewer->priv->motion.current_x));
                     if ((gtk_adjustment_get_value (adjustment) + gtk_adjustment_get_page_size (adjustment)) >
@@ -2484,14 +2481,11 @@ rstto_motion_notify_event (GtkWidget *widget, GdkEventMotion *event)
                         gtk_adjustment_set_value (adjustment,
                                 gtk_adjustment_get_lower (adjustment));
                     }
-                    if (val != gtk_adjustment_get_value (adjustment))
-                        gtk_adjustment_value_changed (adjustment);
                 }
 
                 if (viewer->priv->motion.y != viewer->priv->motion.current_y)
                 {
                     adjustment = viewer->vadjustment;
-                    gint val = gtk_adjustment_get_value (adjustment);
                     gtk_adjustment_set_value (adjustment,
                             viewer->priv->motion.v_val + (viewer->priv->motion.y - viewer->priv->motion.current_y));
                     if ((gtk_adjustment_get_value (adjustment) + gtk_adjustment_get_page_size (adjustment)) >
@@ -2505,8 +2499,6 @@ rstto_motion_notify_event (GtkWidget *widget, GdkEventMotion *event)
                         gtk_adjustment_set_value (adjustment,
                                 gtk_adjustment_get_lower (adjustment));
                     }
-                    if (val != gtk_adjustment_get_value (adjustment))
-                        gtk_adjustment_value_changed (adjustment);
                 }
                 break;
             case RSTTO_IMAGE_VIEWER_MOTION_STATE_BOX_ZOOM:
@@ -2770,14 +2762,6 @@ rstto_button_release_event (GtkWidget *widget, GdkEventButton *event)
                 g_object_thaw_notify(G_OBJECT(viewer->vadjustment));
                 g_object_thaw_notify(G_OBJECT(viewer->hadjustment));
 
-                /*
-                 * Trigger the 'changed' signal, update the rest
-                 * of
-                 * the appliaction.
-                 */
-                gtk_adjustment_changed(viewer->hadjustment);
-                gtk_adjustment_changed(viewer->vadjustment);
-
                 g_signal_emit_by_name(viewer, "scale-changed");
             }
             break;
@@ -3002,8 +2986,9 @@ rstto_image_viewer_get_property (GObject *object, guint property_id, GValue *val
 }
 
 static gboolean
-cb_rstto_image_viewer_refresh (RsttoImageViewer *viewer)
+cb_rstto_image_viewer_refresh (gpointer user_data)
 {
+    RsttoImageViewer *viewer = user_data;
     GtkWidget *widget = GTK_WIDGET (viewer);
 
     gdk_window_invalidate_rect (
@@ -3021,15 +3006,13 @@ rstto_image_viewer_set_show_clock (RsttoImageViewer *viewer, gboolean value)
     if (viewer->priv->props.show_clock)
     {
         viewer->priv->refresh_timeout_id = gdk_threads_add_timeout (
-                15000,
-                (GSourceFunc)cb_rstto_image_viewer_refresh, viewer);
+                15000, cb_rstto_image_viewer_refresh, viewer);
     }
     else
     {
         if (viewer->priv->refresh_timeout_id)
         {
-            g_source_remove (viewer->priv->refresh_timeout_id);
-            viewer->priv->refresh_timeout_id = 0;
+            REMOVE_SOURCE (viewer->priv->refresh_timeout_id);
         }
     }
 }
