@@ -25,14 +25,9 @@
 
 #include <xfconf/xfconf.h>
 #include <gtk/gtk.h>
-#include <gdk/gdkkeysyms.h>
-#include <string.h>
 
 #include <libxfce4ui/libxfce4ui.h>
-#include <libxfce4util/libxfce4util.h>
-#include <libexif/exif-data.h>
 
-#include "util.h"
 #include "file.h"
 #include "image_list.h"
 #include "settings.h"
@@ -54,7 +49,7 @@ typedef struct {
 } RsttoOpenFiles;
 
 static gboolean
-cb_rstto_open_files (RsttoOpenFiles *rof);
+cb_rstto_open_files (gpointer user_data);
 
 static GOptionEntry entries[] =
 {
@@ -95,7 +90,7 @@ main(int argc, char **argv)
     textdomain (GETTEXT_PACKAGE);
     #endif
 
-    if (!gtk_init_with_args (&argc, &argv, "", entries, PACKAGE, &cli_error))
+    if (!gtk_init_with_args (&argc, &argv, NULL, entries, PACKAGE, &cli_error))
     {
         if (cli_error != NULL)
         {
@@ -120,7 +115,7 @@ main(int argc, char **argv)
 
     xfconf_init (NULL);
 
-    gtk_window_set_default_icon_name ("ristretto");
+    gtk_window_set_default_icon_name ("org.xfce.ristretto");
     settings = rstto_settings_new ();
 
     if (FALSE == show_settings)
@@ -138,7 +133,7 @@ main(int argc, char **argv)
             rof.iter = 1;
             rof.window = window;
 
-            gdk_threads_add_idle ((GSourceFunc) cb_rstto_open_files, &rof);
+            gdk_threads_add_idle (cb_rstto_open_files, &rof);
 
             if (TRUE == rstto_settings_get_boolean_property (
                         settings,
@@ -183,8 +178,9 @@ main(int argc, char **argv)
 }
 
 static gboolean
-cb_rstto_open_files (RsttoOpenFiles *rof)
+cb_rstto_open_files (gpointer user_data)
 {
+    RsttoOpenFiles *rof = user_data;
     GFileType file_type;
     GFile *file, *p_file;
     GFileInfo *file_info;
