@@ -17,9 +17,7 @@
  *  02110-1301, USA.
  */
 
-#include <config.h>
 #include <libxfce4ui/libxfce4ui.h>
-#include <libxfce4util/libxfce4util.h>
 
 #include "util.h"
 #include "settings.h"
@@ -35,9 +33,13 @@
 
 
 static void
-rstto_preferences_dialog_init (RsttoPreferencesDialog *);
+rstto_preferences_dialog_init (
+        GTypeInstance *instance,
+        gpointer g_class);
 static void
-rstto_preferences_dialog_class_init(GObjectClass *);
+rstto_preferences_dialog_class_init(
+        gpointer g_class,
+        gpointer class_data);
 
 static void
 rstto_preferences_dialog_dispose (GObject *object);
@@ -65,6 +67,10 @@ cb_show_clock_check_button_toggled (
         GtkToggleButton *button, 
         gpointer user_data);
 static void
+cb_cursor_timeout_button_value_changed (
+        GtkSpinButton *spin_button,
+        gpointer user_data);
+static void
 cb_limit_quality_check_button_toggled (
         GtkToggleButton *button, 
         gpointer user_data);
@@ -123,6 +129,13 @@ struct _RsttoPreferencesDialogPriv
         GtkWidget *clock_frame;
         GtkWidget *clock_label;
         GtkWidget *clock_button;
+
+        GtkWidget *cursor_vbox;
+        GtkWidget *cursor_frame;
+        GtkWidget *cursor_label;
+        GtkWidget *cursor_hbox;
+        GtkWidget *cursor_timeout_label;
+        GtkWidget *cursor_timeout_button;
     } fullscreen_tab;
 
     struct
@@ -157,14 +170,14 @@ rstto_preferences_dialog_get_type (void)
         static const GTypeInfo rstto_preferences_dialog_info = 
         {
             sizeof (RsttoPreferencesDialogClass),
-            (GBaseInitFunc) NULL,
-            (GBaseFinalizeFunc) NULL,
-            (GClassInitFunc) rstto_preferences_dialog_class_init,
-            (GClassFinalizeFunc) NULL,
+            NULL,
+            NULL,
+            rstto_preferences_dialog_class_init,
+            NULL,
             NULL,
             sizeof (RsttoPreferencesDialog),
             0,
-            (GInstanceInitFunc) rstto_preferences_dialog_init,
+            rstto_preferences_dialog_init,
             NULL
         };
 
@@ -179,8 +192,9 @@ rstto_preferences_dialog_get_type (void)
 
 /**
  * rstto_preferences_dialog_init:
- * @dialog: The PreferencesDialog, used for configuring ristretto
- *          properties.
+ * @instance: The PreferencesDialog, used for configuring ristretto
+ *            properties.
+ * @g_class:  unused.
  *
  *
  * This function initializes the preferences-dialog.
@@ -215,14 +229,19 @@ rstto_preferences_dialog_get_type (void)
  *      desktop_frame
  */
 static void
-rstto_preferences_dialog_init (RsttoPreferencesDialog *dialog)
+rstto_preferences_dialog_init (
+        GTypeInstance *instance,
+        gpointer g_class)
 {
     /* Variable Section */
 
+    RsttoPreferencesDialog *dialog = RSTTO_PREFERENCES_DIALOG (instance);
+
     gboolean   bool_invert_zoom_direction;
     gboolean   bool_bgcolor_override;
     guint      uint_slideshow_timeout;
     gboolean   bool_hide_thumbnails_fullscreen;
+    guint      uint_hide_mouse_cursor_fullscreen_timeout;
     gboolean   bool_wrap_images;
     gboolean   bool_maximize_on_startup;
     gboolean   bool_show_clock;
@@ -262,6 +281,7 @@ rstto_preferences_dialog_init (RsttoPreferencesDialog *dialog)
             "bgcolor", &bgcolor,
             "slideshow-timeout", &uint_slideshow_timeout,
             "hide-thumbnails-fullscreen", &bool_hide_thumbnails_fullscreen,
+            "hide-mouse-cursor-fullscreen-timeout", &uint_hide_mouse_cursor_fullscreen_timeout,
             "maximize-on-startup", &bool_maximize_on_startup,
             "wrap-images", &bool_wrap_images,
             "desktop-type", &str_desktop_type,
@@ -362,10 +382,31 @@ rstto_preferences_dialog_init (RsttoPreferencesDialog *dialog)
     gtk_container_add (GTK_CONTAINER (dialog->priv->fullscreen_tab.clock_vbox), dialog->priv->fullscreen_tab.clock_button);
     gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (dialog->priv->fullscreen_tab.clock_button), bool_show_clock);
 
-    g_signal_connect (G_OBJECT (dialog->priv->fullscreen_tab.hide_thumbnails_fullscreen_check_button), 
+    dialog->priv->fullscreen_tab.cursor_vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
+    dialog->priv->fullscreen_tab.cursor_frame = xfce_gtk_frame_box_new_with_content (_("Mouse cursor"), dialog->priv->fullscreen_tab.cursor_vbox);
+    gtk_box_pack_start (GTK_BOX (fullscreen_main_vbox), dialog->priv->fullscreen_tab.cursor_frame, FALSE, FALSE, 0);
+
+    dialog->priv->fullscreen_tab.cursor_label = gtk_label_new (_("The mouse cursor can be automatically hidden after a certain period of inactivity\nwhen the window is fullscreen."));
+    gtk_label_set_line_wrap (GTK_LABEL (dialog->priv->fullscreen_tab.cursor_label), TRUE);
+    gtk_label_set_xalign (GTK_LABEL (dialog->priv->fullscreen_tab.cursor_label), 0.0);
+    gtk_label_set_yalign (GTK_LABEL (dialog->priv->fullscreen_tab.cursor_label), 0.5);
+    gtk_container_add (GTK_CONTAINER (dialog->priv->fullscreen_tab.cursor_vbox), dialog->priv->fullscreen_tab.cursor_label);
+
+    dialog->priv->fullscreen_tab.cursor_hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 6);
+    dialog->priv->fullscreen_tab.cursor_timeout_label = gtk_label_new (_("Period of inactivity (seconds):"));
+    dialog->priv->fullscreen_tab.cursor_timeout_button = gtk_spin_button_new_with_range (0, 3600, 1);
+    gtk_spin_button_set_digits (GTK_SPIN_BUTTON (dialog->priv->fullscreen_tab.cursor_timeout_button), 0);
+    gtk_container_add (GTK_CONTAINER (dialog->priv->fullscreen_tab.cursor_hbox), dialog->priv->fullscreen_tab.cursor_timeout_label);
+    gtk_container_add (GTK_CONTAINER (dialog->priv->fullscreen_tab.cursor_hbox), dialog->priv->fullscreen_tab.cursor_timeout_button);
+    gtk_container_add (GTK_CONTAINER (dialog->priv->fullscreen_tab.cursor_vbox), dialog->priv->fullscreen_tab.cursor_hbox);
+    gtk_spin_button_set_value (GTK_SPIN_BUTTON (dialog->priv->fullscreen_tab.cursor_timeout_button), uint_hide_mouse_cursor_fullscreen_timeout);
+
+    g_signal_connect (G_OBJECT (dialog->priv->fullscreen_tab.hide_thumbnails_fullscreen_check_button),
                       "toggled", G_CALLBACK (cb_hide_thumbnails_fullscreen_check_button_toggled), dialog);
-    g_signal_connect (G_OBJECT (dialog->priv->fullscreen_tab.clock_button), 
+    g_signal_connect (G_OBJECT (dialog->priv->fullscreen_tab.clock_button),
                       "toggled", G_CALLBACK (cb_show_clock_check_button_toggled), dialog);
+    g_signal_connect (G_OBJECT (dialog->priv->fullscreen_tab.cursor_timeout_button),
+                      "value-changed", G_CALLBACK (cb_cursor_timeout_button_value_changed), dialog);
 
     /*
      * Slideshow tab
@@ -513,8 +554,12 @@ rstto_preferences_dialog_init (RsttoPreferencesDialog *dialog)
 }
 
 static void
-rstto_preferences_dialog_class_init (GObjectClass *object_class)
+rstto_preferences_dialog_class_init (
+        gpointer g_class,
+        gpointer class_data)
 {
+    GObjectClass *object_class = g_class;
+
     parent_class = g_type_class_peek_parent (RSTTO_PREFERENCES_DIALOG_CLASS (object_class));
 
     object_class->dispose = rstto_preferences_dialog_dispose;
@@ -544,7 +589,7 @@ rstto_preferences_dialog_new (GtkWindow *parent)
 {
     GtkWidget *dialog = g_object_new (RSTTO_TYPE_PREFERENCES_DIALOG,
                                       "title", _("Image Viewer Preferences"),
-                                      "icon-name", "ristretto",
+                                      "icon-name", "org.xfce.ristretto",
                                       "transient-for", parent,
                                       NULL);
 
@@ -920,6 +965,35 @@ cb_show_clock_check_button_toggled (
             show_clock);
 }
 
+/**
+ * cb_cursor_timeout_button_value_changed:
+ * @button:    The spin-button the user changed value for.
+ * @user_data: The user-data provided when connecting the
+ *             callback-function, the preferences-dialog.
+ *
+ *
+ * This function is called when a user changes the inactivity
+ * timeout via the spin-button. This function then sets the right
+ * property in the ristretto settings container.
+ *
+ * When the property's value is greater than 0, it will serve as
+ * an inactivity timeout to hide the mouse cursor when in
+ * fullscreen mode.
+ */
+static void
+cb_cursor_timeout_button_value_changed (
+        GtkSpinButton *spin_button,
+        gpointer user_data)
+{
+    RsttoPreferencesDialog *dialog = RSTTO_PREFERENCES_DIALOG (user_data);
+    gdouble value = gtk_spin_button_get_value (spin_button);
+
+    rstto_settings_set_uint_property (
+            dialog->priv->settings,
+            "hide-mouse-cursor-fullscreen-timeout",
+            value > 0 ? (guint) value : 0);
+}
+
 /**
  * cb_limit_quality_check_button_toggled:
  * @button:    The check-button the user clicked.
