@@ -17,8 +17,6 @@
  *  02110-1301, USA.
  */
 
-#include <config.h>
-
 #include <glib.h>
 #include <gdk/gdkkeysyms.h>
 #include <xfconf/xfconf.h>
@@ -28,9 +26,11 @@
 #include "settings.h"
 
 static void
-rstto_settings_init (GObject *);
+rstto_settings_init (GTypeInstance *instance,
+                     gpointer       g_class);
 static void
-rstto_settings_class_init (GObjectClass *);
+rstto_settings_class_init (gpointer g_class,
+                           gpointer class_data);
 
 static void
 rstto_settings_dispose (GObject *object);
@@ -48,6 +48,10 @@ rstto_settings_get_property    (GObject    *object,
                                 GValue     *value,
                                 GParamSpec *pspec);
 
+static void
+rstto_xfconf_ensure_gdkrgba (XfconfChannel *channel,
+                             const gchar *property);
+
 static GObjectClass *parent_class = NULL;
 
 static RsttoSettings *settings_object;
@@ -62,6 +66,7 @@ enum
     PROP_SHOW_CLOCK,
     PROP_LIMIT_QUALITY,
     PROP_HIDE_THUMBNAILS_FULLSCREEN,
+    PROP_HIDE_MOUSE_CURSOR_FULLSCREEN_TIMEOUT,
     PROP_WINDOW_WIDTH,
     PROP_WINDOW_HEIGHT,
     PROP_BGCOLOR,
@@ -89,14 +94,14 @@ rstto_settings_get_type (void)
         static const GTypeInfo rstto_settings_info = 
         {
             sizeof (RsttoSettingsClass),
-            (GBaseInitFunc) NULL,
-            (GBaseFinalizeFunc) NULL,
-            (GClassInitFunc) rstto_settings_class_init,
-            (GClassFinalizeFunc) NULL,
+            NULL,
+            NULL,
+            rstto_settings_class_init,
+            NULL,
             NULL,
             sizeof (RsttoSettings),
             0,
-            (GInstanceInitFunc) rstto_settings_init,
+            rstto_settings_init,
             NULL
         };
 
@@ -115,6 +120,7 @@ struct _RsttoSettingsPriv
     gboolean  show_clock;
     gboolean  limit_quality;
     gboolean  hide_thumbnails_fullscreen;
+    guint     hide_mouse_cursor_fullscreen_timeout;
     gchar    *navigationbar_position;
     gboolean  invert_zoom_direction;
     guint     window_width;
@@ -139,11 +145,12 @@ struct _RsttoSettingsPriv
 
 
 static void
-rstto_settings_init (GObject *object)
+rstto_settings_init (GTypeInstance *instance,
+                     gpointer       g_class)
 {
     gchar *accelmap_path = NULL;
 
-    RsttoSettings *settings = RSTTO_SETTINGS (object);
+    RsttoSettings *settings = RSTTO_SETTINGS (instance);
 
     settings->priv = g_new0 (RsttoSettingsPriv, 1);
     settings->priv->channel = xfconf_channel_new ("ristretto");
@@ -187,6 +194,7 @@ rstto_settings_init (GObject *object)
     settings->priv->use_thunar_properties = TRUE;
     settings->priv->maximize_on_startup = TRUE;
     settings->priv->hide_thumbnails_fullscreen = TRUE;
+    settings->priv->hide_mouse_cursor_fullscreen_timeout = 1;
     settings->priv->errors.missing_thumbnailer = TRUE;
     settings->priv->thumbnail_size = THUMBNAIL_SIZE_NORMAL;
 
@@ -259,6 +267,13 @@ rstto_settings_init (GObject *object)
             settings,
             "hide-thumbnails-fullscreen");
 
+    xfconf_g_property_bind (
+            settings->priv->channel,
+            "/window/mouse-cursor/hide-fullscreen-timeout",
+            G_TYPE_UINT,
+            settings,
+            "hide-mouse-cursor-fullscreen-timeout");
+
     xfconf_g_property_bind (
             settings->priv->channel,
             "/slideshow/timeout",
@@ -273,11 +288,14 @@ rstto_settings_init (GObject *object)
             settings,
             "bgcolor-override");
 
+    rstto_xfconf_ensure_gdkrgba (settings->priv->channel, "/window/bgcolor");
     xfconf_g_property_bind_gdkrgba (
             settings->priv->channel,
             "/window/bgcolor",
             settings,
             "bgcolor");
+
+    rstto_xfconf_ensure_gdkrgba (settings->priv->channel, "/window/bgcolor-fullscreen");
     xfconf_g_property_bind_gdkrgba (
             settings->priv->channel,
             "/window/bgcolor-fullscreen",
@@ -344,11 +362,13 @@ rstto_settings_init (GObject *object)
 
 
 static void
-rstto_settings_class_init (GObjectClass *object_class)
+rstto_settings_class_init (gpointer g_class,
+                           gpointer class_data)
 {
     GParamSpec *pspec;
 
-    RsttoSettingsClass *settings_class = RSTTO_SETTINGS_CLASS (object_class);
+    GObjectClass       *object_class = g_class;
+    RsttoSettingsClass *settings_class = g_class;
 
     parent_class = g_type_class_peek_parent (settings_class);
 
@@ -450,6 +470,19 @@ rstto_settings_class_init (GObjectClass *object_class)
             PROP_HIDE_THUMBNAILS_FULLSCREEN,
             pspec);
 
+    pspec = g_param_spec_uint (
+            "hide-mouse-cursor-fullscreen-timeout",
+            "",
+            "",
+            0,
+            3600,
+            1,
+            G_PARAM_READWRITE);
+    g_object_class_install_property (
+            object_class,
+            PROP_HIDE_MOUSE_CURSOR_FULLSCREEN_TIMEOUT,
+            pspec);
+
     pspec = g_param_spec_string (
             "navigationbar-position",
             "",
@@ -686,6 +719,36 @@ rstto_settings_finalize (GObject *object)
     
 }
 
+/**
+ * rstto_xfconf_ensure_gdkrgba:
+ * This method makes sure that the property contains a GdkRGBA value rather than
+ * a GdkColor value, by converting the latter to the former if necessary.
+ */
+static void
+rstto_xfconf_ensure_gdkrgba (XfconfChannel *channel, const gchar *property)
+{
+    guint    rc, gc, bc, ac;
+    gboolean is_gdk_color = xfconf_channel_get_array (channel,
+                                                      property,
+                                                      G_TYPE_UINT, &rc,
+                                                      G_TYPE_UINT, &gc,
+                                                      G_TYPE_UINT, &bc,
+                                                      G_TYPE_UINT, &ac,
+                                                      G_TYPE_INVALID);
+
+    if (is_gdk_color)
+    {
+        GdkRGBA bg = { (gdouble) rc/65535, (gdouble) gc/65535, (gdouble) bc/65535, (gdouble) ac/65535 };
+        xfconf_channel_set_array (channel,
+                                  property,
+                                  G_TYPE_DOUBLE, &bg.red,
+                                  G_TYPE_DOUBLE, &bg.green,
+                                  G_TYPE_DOUBLE, &bg.blue,
+                                  G_TYPE_DOUBLE, &bg.alpha,
+                                  G_TYPE_INVALID);
+    }
+}
+
 
 
 /**
@@ -740,6 +803,9 @@ rstto_settings_set_property    (GObject      *object,
         case PROP_HIDE_THUMBNAILS_FULLSCREEN:
             settings->priv->hide_thumbnails_fullscreen = g_value_get_boolean (value);
             break;
+        case PROP_HIDE_MOUSE_CURSOR_FULLSCREEN_TIMEOUT:
+            settings->priv->hide_mouse_cursor_fullscreen_timeout = g_value_get_uint (value);
+            break;
         case PROP_NAVBAR_POSITION:
             str_val = g_value_get_string (value);
 
@@ -844,6 +910,9 @@ rstto_settings_get_property    (GObject    *object,
         case PROP_HIDE_THUMBNAILS_FULLSCREEN:
             g_value_set_boolean (value, settings->priv->hide_thumbnails_fullscreen);
             break;
+        case PROP_HIDE_MOUSE_CURSOR_FULLSCREEN_TIMEOUT:
+            g_value_set_uint (value, settings->priv->hide_mouse_cursor_fullscreen_timeout);
+            break;
         case PROP_NAVBAR_POSITION:
             g_value_set_string (value, settings->priv->navigationbar_position);
             break;
